@@ -57,10 +57,14 @@ export default function transformProps(chartProps) {
   const xAxisFormatter =
     coltypes[0] === GenericDataType.TEMPORAL
       ? getTimeFormatter(timeFormat)
+      : coltypes[0] === GenericDataType.Numeric
+      ? Number
       : String;
   const yAxisFormatter =
     coltypes[1] === GenericDataType.TEMPORAL
       ? getTimeFormatter(timeFormat)
+      : coltypes[1] === GenericDataType.Numeric
+      ? Number
       : String;
   return {
     width,
