@@ -108,6 +108,7 @@ export type PageHeaderWithActionsProps = {
   showTitlePanelItems: boolean;
   certificatiedBadgeProps?: CertifiedBadgeProps;
   showFaveStar: boolean;
+  showMenuDropdown?: boolean;
   faveStarProps: FaveStarProps;
   titlePanelAdditionalItems: ReactNode;
   rightPanelAdditionalItems: ReactNode;
@@ -129,6 +130,7 @@ export const PageHeaderWithActions = ({
   rightPanelAdditionalItems,
   additionalActionsMenu,
   menuDropdownProps,
+  showMenuDropdown = true,
   tooltipProps,
 }: PageHeaderWithActionsProps) => {
   const theme = useTheme();
@@ -149,25 +151,27 @@ export const PageHeaderWithActions = ({
       <div className="right-button-panel">
         {rightPanelAdditionalItems}
         <div css={additionalActionsContainerStyles}>
-          <AntdDropdown
-            trigger={['click']}
-            overlay={additionalActionsMenu}
-            {...menuDropdownProps}
-          >
-            <Button
-              css={menuTriggerStyles}
-              buttonStyle="tertiary"
-              aria-label={t('Menu actions trigger')}
-              tooltip={tooltipProps?.text}
-              placement={tooltipProps?.placement}
-              data-test="actions-trigger"
+          {showMenuDropdown && (
+            <AntdDropdown
+              trigger={['click']}
+              overlay={additionalActionsMenu}
+              {...menuDropdownProps}
             >
-              <Icons.MoreHoriz
-                iconColor={theme.colors.primary.dark2}
-                iconSize="l"
-              />
-            </Button>
-          </AntdDropdown>
+              <Button
+                css={menuTriggerStyles}
+                buttonStyle="tertiary"
+                aria-label={t('Menu actions trigger')}
+                tooltip={tooltipProps?.text}
+                placement={tooltipProps?.placement}
+                data-test="actions-trigger"
+              >
+                <Icons.MoreHoriz
+                  iconColor={theme.colors.primary.dark2}
+                  iconSize="l"
+                />
+              </Button>
+            </AntdDropdown>
+          )}
         </div>
       </div>
     </div>
