@@ -53,6 +53,8 @@ import { isUserAdmin } from 'src/dashboard/util/permissionUtils';
 import Owner from 'src/types/Owner';
 import AlertReportModal from 'src/features/alerts/AlertReportModal';
 import { AlertObject, AlertState } from 'src/features/alerts/types';
+import { ModifiedInfo } from 'src/components/AuditInfo';
+import { QueryObjectColumns } from 'src/views/CRUD/types';
 
 const extensionsRegistry = getExtensionsRegistry();
 
@@ -303,18 +305,6 @@ function AlertList({
         disableSortBy: true,
         size: 'xl',
       },
-      {
-        Cell: ({
-          row: {
-            original: { created_by },
-          },
-        }: any) =>
-          created_by ? `${created_by.first_name} ${created_by.last_name}` : '',
-        Header: t('Created by'),
-        id: 'created_by',
-        disableSortBy: true,
-        size: 'xl',
-      },
       {
         Cell: ({
           row: {
@@ -329,10 +319,13 @@ function AlertList({
       {
         Cell: ({
           row: {
-            original: { changed_on_delta_humanized: changedOn },
+            original: {
+              changed_on_delta_humanized: changedOn,
+              changed_by: changedBy,
+            },
           },
-        }: any) => <span className="no-wrap">{changedOn}</span>,
-        Header: t('Modified'),
+        }: any) => <ModifiedInfo date={changedOn} user={changedBy} />,
+        Header: t('Last modified'),
         accessor: 'changed_on_delta_humanized',
         size: 'xl',
       },
@@ -407,6 +400,10 @@ function AlertList({
         disableSortBy: true,
         size: 'xl',
       },
+      {
+        accessor: QueryObjectColumns.changed_by,
+        hidden: true,
+      },
     ],
     [canDelete, canEdit, isReportEnabled, toggleActive],
   );
@@ -448,6 +445,13 @@ function AlertList({
 
   const filters: Filters = useMemo(
     () => [
+      {
+        Header: t('Name'),
+        key: 'search',
+        id: 'name',
+        input: 'search',
+        operator: FilterOperator.contains,
+      },
       {
         Header: t('Owner'),
         key: 'owner',
@@ -465,23 +469,6 @@ function AlertList({
         ),
         paginate: true,
       },
-      {
-        Header: t('Created by'),
-        key: 'created_by',
-        id: 'created_by',
-        input: 'select',
-        operator: FilterOperator.relationOneMany,
-        unfilteredLabel: 'All',
-        fetchSelects: createFetchRelated(
-          'report',
-          'created_by',
-          createErrorHandler(errMsg =>
-            t('An error occurred while fetching created by values: %s', errMsg),
-          ),
-          user,
-        ),
-        paginate: true,
-      },
       {
         Header: t('Status'),
         key: 'status',
@@ -504,11 +491,24 @@ function AlertList({
         ],
       },
       {
-        Header: t('Search'),
-        key: 'search',
-        id: 'name',
-        input: 'search',
-        operator: FilterOperator.contains,
+        Header: t('Modified by'),
+        key: 'changed_by',
+        id: 'changed_by',
+        input: 'select',
+        operator: FilterOperator.relationOneMany,
+        unfilteredLabel: t('All'),
+        fetchSelects: createFetchRelated(
+          'report',
+          'changed_by',
+          createErrorHandler(errMsg =>
+            t(
+              'An error occurred while fetching dataset datasource values: %s',
+              errMsg,
+            ),
+          ),
+          user,
+        ),
+        paginate: true,
       },
     ],
     [],
@@ -612,6 +612,9 @@ function AlertList({
               bulkActions={bulkActions}
               bulkSelectEnabled={bulkSelectEnabled}
               disableBulkSelect={toggleBulkSelect}
+              refreshData={refreshData}
+              addDangerToast={addDangerToast}
+              addSuccessToast={addSuccessToast}
               pageSize={PAGE_SIZE}
             />
           );
