@@ -112,6 +112,7 @@ export interface QueryObject {
 export enum QueryObjectColumns {
   id = 'id',
   changed_on = 'changed_on',
+  changed_by = 'changed_by',
   database = 'database',
   database_name = 'database.database_name',
   schema = 'schema',
@@ -138,9 +139,13 @@ export type ImportResourceName =
 
 export interface Tag {
   changed_on_delta_humanized: string;
+  changed_by: Owner;
+  created_on_delta_humanized: string;
   name: string;
   id: number;
-  created_by: object;
+  created_by: Owner;
+  description: string;
+  type: string;
 }
 
 export type DatabaseObject = Partial<Database> &
