@@ -14,8 +14,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from superset.db_engine_specs.sqlite import SqliteEngineSpec
 
+if TYPE_CHECKING:
+    from superset.models.core import Database
+
 
 class ShillelaghEngineSpec(SqliteEngineSpec):
     """Engine for shillelagh"""
@@ -28,3 +35,14 @@ class ShillelaghEngineSpec(SqliteEngineSpec):
 
     allows_joins = True
     allows_subqueries = True
+
+    @classmethod
+    def get_function_names(
+        cls,
+        database: Database,
+    ) -> list[str]:
+        return super().get_function_names(database) + [
+            "sleep",
+            "version",
+            "get_metadata",
+        ]
