@@ -27,9 +27,10 @@ from flask_talisman import Talisman
 from flask_wtf.csrf import CSRFProtect
 from werkzeug.local import LocalProxy
 
+from superset.async_events.async_query_manager import AsyncQueryManager
+from superset.async_events.async_query_manager_factory import AsyncQueryManagerFactory
 from superset.extensions.ssh import SSHManagerFactory
 from superset.extensions.stats_logger import BaseStatsLoggerManager
-from superset.utils.async_query_manager import AsyncQueryManager
 from superset.utils.cache_manager import CacheManager
 from superset.utils.encrypt import EncryptedFieldFactory
 from superset.utils.feature_flag_manager import FeatureFlagManager
@@ -80,11 +81,13 @@ class UIManifestProcessor:
                 loaded_chunks.add(f)
             return filtered_files
 
-        return dict(
-            js_manifest=lambda bundle: get_files(bundle, "js"),
-            css_manifest=lambda bundle: get_files(bundle, "css"),
-            assets_prefix=self.app.config["STATIC_ASSETS_PREFIX"] if self.app else "",
-        )
+        return {
+            "js_manifest": lambda bundle: get_files(bundle, "js"),
+            "css_manifest": lambda bundle: get_files(bundle, "css"),
+            "assets_prefix": self.app.config["STATIC_ASSETS_PREFIX"]
+            if self.app
+            else "",
+        }
 
     def parse_manifest_json(self) -> None:
         try:
@@ -112,7 +115,10 @@ class ProfilingExtension:  # pylint: disable=too-few-public-methods
 
 APP_DIR = os.path.join(os.path.dirname(__file__), os.path.pardir)
 appbuilder = AppBuilder(update_perms=False)
-async_query_manager = AsyncQueryManager()
+async_query_manager_factory = AsyncQueryManagerFactory()
+async_query_manager: AsyncQueryManager = LocalProxy(
+    async_query_manager_factory.instance
+)
 cache_manager = CacheManager()
 celery_app = celery.Celery()
 csrf = CSRFProtect()
