@@ -33,7 +33,7 @@ from flask_appbuilder.models.mixins import AuditMixin
 from sqlalchemy import Column, DateTime, Enum, ForeignKey, Integer, String
 from sqlalchemy.ext.declarative import declarative_base, declared_attr
 
-from superset.tags.models import ObjectTypes, TagTypes
+from superset.tags.models import ObjectType, TagType
 from superset.utils.core import get_user_id
 
 Base = declarative_base()
@@ -77,7 +77,7 @@ class Tag(Base, AuditMixinNullable):
 
     id = Column(Integer, primary_key=True)
     name = Column(String(250), unique=True)
-    type = Column(Enum(TagTypes))
+    type = Column(Enum(TagType))
 
 
 class TaggedObject(Base, AuditMixinNullable):
@@ -86,7 +86,7 @@ class TaggedObject(Base, AuditMixinNullable):
     id = Column(Integer, primary_key=True)
     tag_id = Column(Integer, ForeignKey("tag.id"))
     object_id = Column(Integer)
-    object_type = Column(Enum(ObjectTypes))
+    object_type = Column(Enum(ObjectType))
 
 
 class User(Base):
