@@ -14,7 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""add on delete cascade for embedded dashboards
+"""add on delete cascade for embedded_dashboards
 
 Revision ID: 4448fa6deeb1
 Revises: 8ace289026f3
