@@ -15,14 +15,11 @@
 # specific language governing permissions and limitations
 # under the License.
 from . import (
-    access_requests,
     alerts,
     api,
     base,
     core,
     css_templates,
-    dashboard,
-    datasource,
     dynamic_plugins,
     health,
     redirects,
