@@ -22,6 +22,7 @@ import logging
 import os
 import traceback
 from datetime import datetime
+from importlib.resources import files
 from typing import Any, Callable, cast
 
 import simplejson as json
@@ -47,7 +48,6 @@ from flask_babel import get_locale, gettext as __, lazy_gettext as _
 from flask_jwt_extended.exceptions import NoAuthorizationError
 from flask_wtf.csrf import CSRFError
 from flask_wtf.form import FlaskForm
-from pkg_resources import resource_filename
 from sqlalchemy import exc
 from sqlalchemy.orm import Query
 from werkzeug.exceptions import HTTPException
@@ -95,6 +95,7 @@ FRONTEND_CONF_KEYS = (
     "SQL_MAX_ROW",
     "SUPERSET_WEBSERVER_DOMAINS",
     "SQLLAB_SAVE_WARNING_MESSAGE",
+    "SQLLAB_DEFAULT_DBID",
     "DISPLAY_MAX_ROW",
     "GLOBAL_ASYNC_QUERIES_TRANSPORT",
     "GLOBAL_ASYNC_QUERIES_POLLING_DELAY",
@@ -121,6 +122,7 @@ FRONTEND_CONF_KEYS = (
     "ALERT_REPORTS_DEFAULT_WORKING_TIMEOUT",
     "NATIVE_FILTER_DEFAULT_ROW_LIMIT",
     "PREVENT_UNSAFE_DEFAULT_URLS_ON_DATASET",
+    "JWT_ACCESS_CSRF_COOKIE_NAME",
 )
 
 logger = logging.getLogger(__name__)
@@ -143,12 +145,8 @@ def json_error_response(
     msg: str | None = None,
     status: int = 500,
     payload: dict[str, Any] | None = None,
-    link: str | None = None,
 ) -> FlaskResponse:
-    if not payload:
-        payload = {"error": f"{msg}"}
-    if link:
-        payload["link"] = link
+    payload = payload or {"error": f"{msg}"}
 
     return Response(
         json.dumps(payload, default=utils.json_iso_dttm_ser, ignore_nan=True),
@@ -162,8 +160,7 @@ def json_errors_response(
     status: int = 500,
     payload: dict[str, Any] | None = None,
 ) -> FlaskResponse:
-    if not payload:
-        payload = {}
+    payload = payload or {}
 
     payload["errors"] = [dataclasses.asdict(error) for error in errors]
     return Response(
@@ -202,7 +199,7 @@ def deprecated(
 
     def _deprecated(f: Callable[..., FlaskResponse]) -> Callable[..., FlaskResponse]:
         def wraps(self: BaseSupersetView, *args: Any, **kwargs: Any) -> FlaskResponse:
-            messsage = (
+            message = (
                 "%s.%s "
                 "This API endpoint is deprecated and will be removed in version %s"
             )
@@ -212,9 +209,9 @@ def deprecated(
                 eol_version,
             ]
             if new_target:
-                messsage += " . Use the following API endpoint instead: %s"
+                message += " . Use the following API endpoint instead: %s"
                 logger_args.append(new_target)
-            logger.warning(messsage, *logger_args)
+            logger.warning(message, *logger_args)
             return f(self, *args, **kwargs)
 
         return functools.update_wrapper(wraps, f)
@@ -294,10 +291,13 @@ class BaseSupersetView(BaseView):
             mimetype="application/json",
         )
 
-    def render_app_template(self) -> FlaskResponse:
+    def render_app_template(
+        self, extra_bootstrap_data: dict[str, Any] | None = None
+    ) -> FlaskResponse:
         payload = {
             "user": bootstrap_user_data(g.user, include_perms=True),
             "common": common_bootstrap_payload(),
+            **(extra_bootstrap_data or {}),
         }
         return self.render_template(
             "superset/spa.html",
@@ -333,21 +333,16 @@ def get_environment_tag() -> dict[str, Any]:
 
 
 def menu_data(user: User) -> dict[str, Any]:
-    menu = appbuilder.menu.get_data()
+    languages = {
+        lang: {**appbuilder.languages[lang], "url": appbuilder.get_url_for_locale(lang)}
+        for lang in appbuilder.languages
+    }
 
-    languages = {}
-    for lang in appbuilder.languages:
-        languages[lang] = {
-            **appbuilder.languages[lang],
-            "url": appbuilder.get_url_for_locale(lang),
-        }
-    brand_text = appbuilder.app.config["LOGO_RIGHT_TEXT"]
-    if callable(brand_text):
+    if callable(brand_text := appbuilder.app.config["LOGO_RIGHT_TEXT"]):
         brand_text = brand_text()
-    build_number = appbuilder.app.config["BUILD_NUMBER"]
 
     return {
-        "menu": menu,
+        "menu": appbuilder.menu.get_data(),
         "brand": {
             "path": appbuilder.app.config["LOGO_TARGET_PATH"] or "/superset/welcome/",
             "icon": appbuilder.app_icon,
@@ -367,9 +362,9 @@ def menu_data(user: User) -> dict[str, Any]:
             "documentation_text": appbuilder.app.config["DOCUMENTATION_TEXT"],
             "version_string": appbuilder.app.config["VERSION_STRING"],
             "version_sha": appbuilder.app.config["VERSION_SHA"],
-            "build_number": build_number,
+            "build_number": appbuilder.app.config["BUILD_NUMBER"],
             "languages": languages,
-            "show_language_picker": len(languages.keys()) > 1,
+            "show_language_picker": len(languages) > 1,
             "user_is_anonymous": user.is_anonymous,
             "user_info_url": None
             if is_feature_enabled("MENU_HIDE_USER_INFO")
@@ -378,7 +373,7 @@ def menu_data(user: User) -> dict[str, Any]:
             "user_login_url": appbuilder.get_url_for_login,
             "user_profile_url": None
             if user.is_anonymous or is_feature_enabled("MENU_HIDE_USER_INFO")
-            else "/superset/profile/",
+            else "/profile/",
             "locale": session.get("locale", "en"),
         },
     }
@@ -480,7 +475,7 @@ def show_http_exception(ex: HTTPException) -> FlaskResponse:
         and not config["DEBUG"]
         and ex.code in {404, 500}
     ):
-        path = resource_filename("superset", f"static/assets/{ex.code}.html")
+        path = files("superset") / f"static/assets/{ex.code}.html"
         return send_file(path, max_age=0), ex.code
 
     return json_errors_response(
@@ -502,7 +497,7 @@ def show_http_exception(ex: HTTPException) -> FlaskResponse:
 def show_command_errors(ex: CommandException) -> FlaskResponse:
     logger.warning("CommandException", exc_info=True)
     if "text/html" in request.accept_mimetypes and not config["DEBUG"]:
-        path = resource_filename("superset", "static/assets/500.html")
+        path = files("superset") / "static/assets/500.html"
         return send_file(path, max_age=0), 500
 
     extra = ex.normalized_messages() if isinstance(ex, CommandInvalidError) else {}
@@ -524,7 +519,7 @@ def show_command_errors(ex: CommandException) -> FlaskResponse:
 def show_unexpected_exception(ex: Exception) -> FlaskResponse:
     logger.exception(ex)
     if "text/html" in request.accept_mimetypes and not config["DEBUG"]:
-        path = resource_filename("superset", "static/assets/500.html")
+        path = files("superset") / "static/assets/500.html"
         return send_file(path, max_age=0), 500
 
     return json_errors_response(
@@ -584,7 +579,9 @@ def validate_json(form: Form, field: Field) -> None:  # pylint: disable=unused-a
         json.loads(field.data)
     except Exception as ex:
         logger.exception(ex)
-        raise Exception(_("json isn't valid")) from ex
+        raise Exception(  # pylint: disable=broad-exception-raised
+            _("json isn't valid")
+        ) from ex
 
 
 class YamlExportMixin:  # pylint: disable=too-few-public-methods
