@@ -14,10 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Optional
+from typing import Any, Optional, TypedDict
 
 from marshmallow import fields, post_load, pre_load, Schema, validate
-from typing_extensions import TypedDict
 
 from superset import app
 from superset.charts.schemas import ChartDataExtrasSchema, ChartDataFilterSchema
@@ -30,6 +29,7 @@ class ExternalMetadataParams(TypedDict):
     schema_name: str
     table_name: str
     normalize_columns: Optional[bool]
+    always_filter_main_dttm: Optional[bool]
 
 
 get_external_metadata_schema = {
@@ -38,6 +38,7 @@ get_external_metadata_schema = {
     "schema_name": "string",
     "table_name": "string",
     "normalize_columns": "boolean",
+    "always_filter_main_dttm": "boolean",
 }
 
 
@@ -47,8 +48,9 @@ class ExternalMetadataSchema(Schema):
     schema_name = fields.Str(allow_none=True)
     table_name = fields.Str(required=True)
     normalize_columns = fields.Bool(allow_none=True)
+    always_filter_main_dttm = fields.Bool(allow_none=True)
 
-    # pylint: disable=no-self-use,unused-argument
+    # pylint: disable=unused-argument
     @post_load
     def normalize(
         self,
@@ -61,6 +63,7 @@ class ExternalMetadataSchema(Schema):
             schema_name=data.get("schema_name", ""),
             table_name=data["table_name"],
             normalize_columns=data["normalize_columns"],
+            always_filter_main_dttm=data["always_filter_main_dttm"],
         )
 
 
@@ -79,7 +82,7 @@ class SamplesPayloadSchema(Schema):
     )
 
     @pre_load
-    # pylint: disable=no-self-use, unused-argument
+    # pylint: disable=unused-argument
     def handle_none(self, data: dict[str, Any], **kwargs: Any) -> dict[str, Any]:
         if data is None:
             return {}
