@@ -15,8 +15,6 @@
 # specific language governing permissions and limitations
 # under the License.
 # isort:skip_file
-from datetime import datetime
-from typing import Tuple, Type
 
 from tests.integration_tests.test_app import app
 from tests.integration_tests.base_tests import SupersetTestCase
