@@ -54,8 +54,8 @@ def session_with_data(session: Session) -> Iterator[Session]:
 def test_delete_ssh_tunnel_command(
     mocker: MockFixture, session_with_data: Session
 ) -> None:
+    from superset.commands.database.ssh_tunnel.delete import DeleteSSHTunnelCommand
     from superset.daos.database import DatabaseDAO
-    from superset.databases.ssh_tunnel.commands.delete import DeleteSSHTunnelCommand
     from superset.databases.ssh_tunnel.models import SSHTunnel
 
     result = DatabaseDAO.get_ssh_tunnel(1)
@@ -64,7 +64,7 @@ def test_delete_ssh_tunnel_command(
     assert isinstance(result, SSHTunnel)
     assert 1 == result.database_id
     mocker.patch(
-        "superset.databases.ssh_tunnel.commands.delete.is_feature_enabled",
+        "superset.commands.database.ssh_tunnel.delete.is_feature_enabled",
         return_value=True,
     )
     DeleteSSHTunnelCommand(1).run()
