@@ -27,15 +27,16 @@ def test_create_ssh_tunnel():
 
     db = Database(id=1, database_name="my_database", sqlalchemy_uri="sqlite://")
 
-    properties = {
-        "database_id": db.id,
-        "server_address": "123.132.123.1",
-        "server_port": "3005",
-        "username": "foo",
-        "password": "bar",
-    }
-
-    result = SSHTunnelDAO.create(properties, commit=False)
+    result = SSHTunnelDAO.create(
+        attributes={
+            "database_id": db.id,
+            "server_address": "123.132.123.1",
+            "server_port": "3005",
+            "username": "foo",
+            "password": "bar",
+        },
+        commit=False,
+    )
 
     assert result is not None
     assert isinstance(result, SSHTunnel)
